@@ -30,7 +30,7 @@ def Main_FCD_pipeline(bids_dir, output_dir, work_dir, analysis_mode, participant
     import nipype.pipeline.engine as pe
     from niworkflows.interfaces.bids import BIDSFreeSurferDir
     from nipype.interfaces.io import DataFinder
-    from fcdproc.utils.misc import convert_list_2_str
+    from fcdproc.utils.misc import convert_list_2_str, convert_str_2_list
     from fcdproc.workflow.modeling import pca_gauss_detector_modeling_wf
 
     fcdproc_wf = pe.Workflow(name='fcdproc_wf')
@@ -39,6 +39,10 @@ def Main_FCD_pipeline(bids_dir, output_dir, work_dir, analysis_mode, participant
     if not os.path.exists(fcdproc_dir):
         os.makedirs(fcdproc_dir)
 
+    controls=convert_str_2_list(controls)
+    pt_positive=convert_str_2_list(pt_positive)
+    pt_negative=convert_str_2_list(pt_negative)
+
     fsdir = pe.Node(
         BIDSFreeSurferDir(
             derivatives=output_dir,
@@ -138,8 +142,6 @@ def init_single_subject_wf(subject_id, bids_dir, output_dir, work_dir):
     subject_data = collect_data(bids_dir, subject_id, bids_validate=True)[0]
     mask_data = os.path.isfile(bids_dir+'/mask/'+subject_id+'/fcd.msk.nii')
     
-
-    spaces = SpatialReferences(['anat', 'fsnative', 'fsaverage'])
     
     workflow = pe.Workflow(name=name)
     fcdproc_dir = os.path.join(output_dir+'/fcdproc/')   
